local VERSION = tonumber(("$Revision: 41 $"):match("%d+"))

local Spyglass = Spyglass

if Spyglass.revision < VERSION then
	Spyglass.version = "r" .. VERSION
	Spyglass.revision = VERSION
	Spyglass.date = ("$Date: 2008-02-09 08:50:46 +0000 (Sat, 09 Feb 2008) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

local Crayon = AceLibrary('Crayon-2.0')
local Tablet = AceLibrary("Tablet-2.0")
local L = AceLibrary("AceLocale-2.2"):new("Spyglass")

local options = {
    type = 'group',
    args = {
        show = {
            type = 'execute',
            name = L['Show Inspection Window'],
            desc = L['Show the inspection window. (displaying the last person inspected)'],
            func = function() Spyglass:ShowWindow() end,
            order = 1,
        },
        
        spacer = {
            type = 'header',
            name = ' ',
            order = 2,
        },
        
        keep = {
            type = 'toggle',
            name = L['Store Data'],
            desc = L['Keep user data.'],
            get = function() return Spyglass.db.profile.storeEquipment end,
            set = function(val) Spyglass:SetSavedEquipment(val) end,
            map = { [true]=L['Enabled'], [false]=L['Disabled'] },
            order = 3,
        },
        
        spacer2 = {
            type = 'header',
            name = ' ',
            order = 4,
        },
        
        clearData = {
            type = 'execute',
            name = L['Clear Data'],
            desc = L['Clear all the currently stored data'],
            func = function() Spyglass:ClearUnitInfo() end,
            order = 5,
        },
    },
}

Spyglass.hasIcon = "Interface\\Icons\\INV_Misc_Spyglass_03"

function Spyglass:InitializeMenu()
	self.hasNoColor = true
	self.cannotDetachTooltip = true
	self.hideWithoutStandby = true
	self.clickableTooltip = true
	self.defaultMinimapPosition = 285
	
	self.OnMenuRequest = options
	
    self.classColors = {}
    for k, v in pairs(_G.RAID_CLASS_COLORS) do
        self.classColors[k] = string.format("%02x%02x%02x", v.r*255, v.g*255, v.b*255)
    end
	
	self:RegisterChatCommand('/spyglass', '/spy', options)
end

----------------------------
-- FuBar Config

function Spyglass:OnTooltipUpdate()
    if self:IsActive() then
        local cat = Tablet:AddCategory(
            'columns', 2,
            'text', L['Last Inspected Unit']
        )
        
        local lastInspected = self.db.profile.lastInspected
        local info = self:GetUnitInfo(lastInspected)
        local name
        
        if info then
            name = Crayon:Colorize(self.classColors[info.localClass], info.name)
        else
            name = L['nobody']
        end
        
        cat:AddLine(
            'text2', name,
            'func', 'MenuSelectPlayer', 'arg1', self, 'arg2', lastInspected
        )
        
        cat = Tablet:AddCategory(
            'columns', 3,
            'text', L['Saved Units']
        )
        
        local classColor
        
        for i, name in ipairs(Spyglass:GetCachedPlayerNames()) do
            info = self:GetUnitInfo(name)
            classColor = self.classColors[info.localClass]
            
            cat:AddLine('text', Crayon:Colorize(classColor, info.name),
                        'text2', info.level,
                        'text3', Crayon:Colorize(classColor, info.class),
                        'func', 'MenuSelectPlayer', 'arg1', self, 'arg2', name)
        end
        
        Tablet:SetHint(L["|cffeda55fClick|r to toggle the inspect window."])
    else
        Tablet:SetHint(L["|cffeda55fDisabled|r"])
    end
end

function Spyglass:MenuSelectPlayer(name)
    if IsControlKeyDown() then
        self:RemoveUnitInfo(name)
        self:UpdateTooltip()
    else
        self:SetInspectPlayer(name)
    end
end

function Spyglass:OnClick(button)
    self:ShowWindow()
end

